# NeuroTools

A Python module for LFP and spikes analysis. It includes a collection of routines for brain signals analysis, circular statistics and spatial maps.

Please read the documentation https://github.com/ivanmysin/NeuroTools

This module requires NumPy, SciPy. In addition, you will also need matplotlib to run the examples.

The samples scripts illustrates the usage of functions. Results are plotted in figures similar to the sample images.

## Installation

We recommend using PyPI to install this package.

```bash
python3 -m pip install neurotools
```

Or, you can download the code and run the below line within the top level folder.
```bash
python3 setup.py install
```
## Authors

The module is being developed by members of the Laboratory of the Neuron System Organization of the Institute of Theoretical and Experimental Biophysics of the Russian Academy of Sciences, Pushchino

Ivan Mysin, Sergey Dubrovin, Sergey Skorokhod, Artem Vasilev
